#############################################
# 
# JAGS code for assessing the effects of 
# species loss on productivity, corresponding
# to the equations 1-3 in the maintext.
# Code tested in "R 3.3.1" with package 
# "rjags 4-6" and "JAGS 4.3.0"
# Version: Jan. 24, 2019
# Programmer: Yuxin Chen
# Contact: chenyux9@gmail.com
# 
###############################################

#-----------------------
# Note for variables
#-----------------------
# r_comm: random effect for community composition
# r_plot: random effect for plot

model
{
# equation 1 in the maintext
for (i in 1:N){
y_mu[i] <- alpha0[age_level[i]] + alpha1 * site[i] + alpha2[age_level[i]] * log_SR[i] +
              r_comm[comm[i]] + r_plot[plot[i]]
y[i] ~ dnorm(y_mu[i], tau_y[age_level[i]])
}

# equations 2 and 3 in the maintext
for (j in 1:N_age){
alpha0_mu[j] = beta0_0 + beta0_1 * age_level_c[j]
alpha2_mu[j] = beta2_0 + beta2_1 * age_level_c[j]
alpha0[j] ~ dnorm(alpha0_mu[j], alpha0_tau)
alpha2[j] ~ dnorm(alpha2_mu[j], alpha2_tau)
tau_y[j] ~ dgamma(0.001, 0.001)
sd_y[j] <- pow(tau_y[j], -0.5)
}

for (k in 1:N_comm){
r_comm[k] ~ dnorm(0, tau_comm)
}

for (l in 1:N_plot){
r_plot[l] ~ dnorm(0, tau_plot)
}

alpha1 ~ dnorm(0, 0.01)
beta0_0 ~ dnorm(0, 0.01)
beta0_1 ~ dnorm(0, 0.01)
beta2_0 ~ dnorm(0, 0.01)
beta2_1 ~ dnorm(0, 0.01)
alpha0_tau ~ dgamma(0.001, 0.001)
alpha2_tau ~ dgamma(0.001, 0.001)
sd_0 <- pow(alpha0_tau, -0.5)
sd_2 <- pow(alpha2_tau, -0.5)
tau_comm ~ dgamma(0.001, 0.001)
sd_comm <- pow(tau_comm, -0.5)
tau_plot ~ dgamma(0.001, 0.001)
sd_plot <- pow(tau_plot, -0.5)
}
